@@ -44,7 +44,7 @@ our @EXPORT_OK = qw(get post put delete postFile putFile);
 ## CONSTANTS
 #####
 our $TIMEOUT = 10;
-our $VERSION = "1.2.5";
+our $VERSION = "1.2.6";
 #####
 ## VARIABLES
 #####
@@ -104,11 +104,16 @@ sub new {
 		$rc = $client->responseCode ();
 		if ($rc-$rc%100 == 200) {
 			my $jHash = decode_json ($authJSON);
-			if ($jHash->[0]->{'user'} ne $self->{'login'}) {
-# should this really happen ?
-				$rc = 403;
-			}
-			else {
+			if (defined $jHash->[0]) {
+				if ($jHash->[0]->{'user'} ne $self->{'login'}) {
+	# should this really happen ?
+					$rc = 403;
+				}
+				else {
+					$rc = 200;
+				}
+			} else {
+	# empty hash, but res = OK
 				$rc = 200;
 			}
 		}
